==> phonon-backend-vlc_0.10.1.orig.tar.xz: phonon-vlc-0.10.1/src/vlc.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=@PHONON_VLC_MIME_TYPES@;
X-KDE-Library=phonon_vlc
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_VLC_VERSION@
X-KDE-PhononBackendInfo-Website=http://www.videolan.org/
Icon=vlc
InitialPreference=20

Name=VLC
Name[ast]=VLC
Name[bg]=VLC
Name[bs]=VLC
Name[ca]=VLC
Name[ca@valencia]=VLC
Name[cs]=VLC
Name[da]=VLC
Name[de]=VLC
Name[el]=VLC
Name[en_GB]=VLC
Name[es]=VLC
Name[et]=VLC
Name[eu]=VLC
Name[fa]=وی‌ال‌سی (VLC)
Name[fi]=VLC
Name[fr]=VLC
Name[ga]=VLC
Name[gl]=VLC
Name[hu]=VLC
Name[it]=VLC
Name[kk]=VLC
Name[ko]=VLC
Name[lt]=VLC
Name[mr]=व्ही-एल-सी
Name[nb]=VLC
Name[nds]=VLC
Name[nl]=VLC
Name[nn]=VLC
Name[pa]=VLC
Name[pl]=VLC
Name[pt]=VLC
Name[pt_BR]=VLC
Name[ro]=VLC
Name[ru]=VLC
Name[sk]=VLC
Name[sl]=VLC
Name[sr]=ВЛЦ
Name[sr@ijekavian]=ВЛЦ
Name[sr@ijekavianlatin]=VLC
Name[sr@latin]=VLC
Name[sv]=VLC
Name[tr]=VLC
Name[ug]=VLC
Name[uk]=VLC
Name[x-test]=xxVLCxx
Name[zh_CN]=VLC
Name[zh_TW]=VLC

Comment=Phonon VLC backend
Comment[bg]=Ядро VLC за Phonon
Comment[bs]=VLC kao pozadina za Phonon
Comment[ca]=Dorsal del VLC pel Phonon
Comment[ca@valencia]=Dorsal del VLC pel Phonon
Comment[cs]=Podpůrná vrstva VLC
Comment[da]=Phonon VLC-motor
Comment[de]=Phonon-Treiber für VLC
Comment[el]=Σύστημα υποστήριξης Phonon VLC
Comment[en_GB]=Phonon VLC backend
Comment[es]=Motor VLC para Phonon
Comment[et]=Phononi VLC taustaprogramm
Comment[eu]=Phonon-en VLC bizkarraldekoa
Comment[fa]=پسانه‌ی وی‌ال‌سی برای فنون (Phonon VLC backend)
Comment[fi]=Phonon VLC -taustajärjestelmä
Comment[fr]=Module VLC pour Phonon
Comment[ga]=Inneall VLC Phonon
Comment[gl]=Infraestrutura de VLC para Phonon
Comment[hu]=Phonon VLC-backend
Comment[it]=Motore VLC di Phonon
Comment[kk]=Phonon VLC тетігі
Comment[ko]=Phonon VLC 백엔드
Comment[lt]=Phonon VLC galinė sąsaja
Comment[mr]=फोनॉन व्ही-एल-सी बॅकएन्ड
Comment[nb]=Phonon VLC-motor
Comment[nds]=VLC-Hülpprogramm för Phonon
Comment[nl]=VLC-backend van Phonon
Comment[nn]=VLC-motor for Phonon
Comment[pa]=ਫੋਨੋਨ VLC ਬੈਕਐਂਡ
Comment[pl]=Silnik VLC dla Phonon
Comment[pt]=Infra-estrutura do VLC para o Phonon
Comment[pt_BR]=Infraestrutura do VLC para o Phonon
Comment[ro]=Suportul VLC pentru Phonon
Comment[ru]=Механизм VLC для Phonon
Comment[sk]=Backend Phonon VLC
Comment[sl]=Zaledje VLC za Phonon
Comment[sr]=ВЛЦ као позадина Фонона
Comment[sr@ijekavian]=ВЛЦ као позадина Фонона
Comment[sr@ijekavianlatin]=VLC kao pozadina Phonona
Comment[sr@latin]=VLC kao pozadina Phonona
Comment[sv]=Phonon VLC-gränssnitt
Comment[tr]=Phonon VLC arka ucu
Comment[ug]=Phonon VLC ئارقا ئۇچى
Comment[uk]=Модуль VLC Phonon
Comment[x-test]=xxPhonon VLC backendxx
Comment[zh_CN]= Phonon VLC 后端
Comment[zh_TW]=Phonon VLC 後端介面

==> phonon-backend-vlc-0.10.3.tar.xz: phonon-vlc-0.10.3/src/vlc.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=@PHONON_VLC_MIME_TYPES@;
X-KDE-Library=phonon_vlc
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_VLC_VERSION@
X-KDE-PhononBackendInfo-Website=http://www.videolan.org/
Icon=vlc
InitialPreference=20

Name=VLC
Name[ca]=VLC
Name[ca@valencia]=VLC
Name[cs]=VLC
Name[de]=VLC
Name[en_GB]=VLC
Name[es]=VLC
Name[eu]=VLC
Name[fi]=VLC
Name[fr]=VLC
Name[gl]=VLC
Name[id]=VLC
Name[it]=VLC
Name[ko]=VLC
Name[nb]=VLC
Name[nl]=VLC
Name[nn]=VLC
Name[pl]=VLC
Name[pt_BR]=VLC
Name[sk]=VLC
Name[sr]=ВЛЦ
Name[sr@ijekavian]=ВЛЦ
Name[sr@ijekavianlatin]=VLC
Name[sr@latin]=VLC
Name[sv]=VLC
Name[uk]=VLC
Name[x-test]=xxVLCxx
Name[zh_CN]=VLC

Comment=Phonon VLC backend
Comment[ca]=Dorsal del VLC pel Phonon
Comment[ca@valencia]=Dorsal del VLC pel Phonon
Comment[cs]=Podpůrná vrstva VLC
Comment[de]=Phonon-Treiber für VLC
Comment[en_GB]=Phonon VLC backend
Comment[es]=Motor VLC para Phonon
Comment[eu]=Phonon VLC bizkarraldekoa
Comment[fi]=Phonon VLC -taustajärjestelmä
Comment[fr]=Module VLC pour Phonon
Comment[gl]=Infraestrutura de VLC para Phonon
Comment[id]=Backend phonon VLC
Comment[it]=Motore VLC di Phonon
Comment[ko]=Phonon VLC 백엔드
Comment[nb]=Phonon VLC-motor
Comment[nl]=VLC-backend van Phonon
Comment[nn]=VLC-motor for Phonon
Comment[pl]=Silnik VLC Phonona
Comment[pt_BR]=Infraestrutura VLC do Phonon
Comment[sk]=Backend Phonon VLC
Comment[sr]=ВЛЦ као позадина Фонона
Comment[sr@ijekavian]=ВЛЦ као позадина Фонона
Comment[sr@ijekavianlatin]=VLC kao pozadina Phonona
Comment[sr@latin]=VLC kao pozadina Phonona
Comment[sv]=Phonon VLC-gränssnitt
Comment[uk]=Модуль VLC Phonon
Comment[x-test]=xxPhonon VLC backendxx
Comment[zh_CN]= Phonon VLC 后端
